![shortipy logo](https://github.com/CoffeePerry/shortipy/blob/main/art/shortipy.png?raw=true)

![GitHub release (latest by date)](https://img.shields.io/github/v/release/CoffeePerry/shortipy)
![PyPI](https://img.shields.io/pypi/v/shortipy?logo=PyPI&logoColor=white)
![PyPI - Status](https://img.shields.io/pypi/status/shortipy)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/shortipy?logo=Python&logoColor=white)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/shortipy)

[![Flask](https://img.shields.io/badge/framework-Flask-black?logo=Flask&logoColor=white)](https://github.com/pallets/flask/)

[![GitHub license](https://img.shields.io/github/license/CoffeePerry/shortipy)](https://github.com/CoffeePerry/shortipy/blob/master/LICENSE)

[![GitHub issues](https://img.shields.io/github/issues/CoffeePerry/shortipy)](https://github.com/CoffeePerry/shortipy/issues)

# shortipy

**Shortipy** is a *RESTful Web API*, written in *Python* language and based on the *Flask* micro-framework, designed to manage shortened links. 
